@@ -7,7 +7,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: common.cpp 3524 2007-04-19 07:50:15Z mosu $
+   $Id: common.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    helper functions, common variables
 
@@ -62,7 +62,8 @@ using namespace libebml;
 #include "random.h"
 #include "smart_pointers.h"
 
-int verbose = 1;
+const string empty_string("");
+int verbose            = 1;
 bool suppress_warnings = false;
 
 bitvalue_c::bitvalue_c(int nbitsize) {
@@ -796,11 +797,11 @@ split(const char *src,
 
 string
 join(const char *pattern,
-     vector<string> &strings) {
+     const vector<string> &strings) {
   string dst;
-  uint32_t i;
+  int i;
 
-  if (strings.size() == 0)
+  if (strings.empty())
     return "";
   dst = strings[0];
   for (i = 1; i < strings.size(); i++) {
@@ -1347,7 +1348,7 @@ mxmsg(int level,
       va_list ap) {
   string new_fmt, output;
   bool nl;
-  char *prefix;
+  const char *prefix;
 
   fix_format(fmt, new_fmt);
 
