@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: common.h 3581 2007-08-19 09:24:10Z mosu $
+   $Id: common.h 3777 2008-03-04 07:35:53Z mosu $
 
    definitions used in all programs, helper functions
 
@@ -20,6 +20,7 @@
 
 #include <stdarg.h>
 
+#include <cstring>
 #include <string>
 #include <vector>
 
@@ -55,7 +56,7 @@ namespace libebml {
 
 using namespace libebml;
 
-#define VERSIONNAME "Another Place To Fall"
+#define VERSIONNAME "Turn It On Again"
 #define VERSIONINFO "mkvmerge v" VERSION " ('" VERSIONNAME "')"
 #define BUGMSG _("This should not have happened. Please contact the author " \
                  "Moritz Bunkus <moritz@bunkus.org> with this error/warning " \
@@ -237,7 +238,7 @@ split(const string &src,
       int max_num = -1) {
   return split(src.c_str(), pattern.c_str(), max_num);
 }
-string MTX_DLL_API join(const char *pattern, vector<string> &strings);
+string MTX_DLL_API join(const char *pattern, const vector<string> &strings);
 void MTX_DLL_API strip(string &s, bool newlines = false);
 void MTX_DLL_API strip(vector<string> &v, bool newlines = false);
 string &MTX_DLL_API shrink_whitespace(string &s);
@@ -264,6 +265,8 @@ starts_with_case(const string &s,
 string MTX_DLL_API upcase(const string &s);
 string MTX_DLL_API downcase(const string &s);
 
+extern const string MTX_DLL_API empty_string;
+
 #define irnd(a) ((int64_t)((double)(a) + 0.5))
 #define iabs(a) ((a) < 0 ? (a) * -1 : (a))
 
