@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mm_io.cpp 3571 2007-07-10 20:13:14Z mosu $
+   $Id: mm_io.cpp 3759 2008-02-27 15:32:22Z mosu $
 
    IO callback class implementation
 
@@ -63,7 +63,7 @@ mm_file_io_c::mm_file_io_c(const string &path,
   file_name(path) {
 
   string local_path;
-  char *cmode;
+  const char *cmode;
   struct stat st;
 # if HAVE_POSIX_FADVISE
   int advise;
@@ -174,6 +174,7 @@ mm_file_io_c::write(const void *buffer,
 # endif
 
   m_current_position += bwritten;
+  cached_size         = -1;
 
   return bwritten;
 }
@@ -223,11 +224,12 @@ mm_file_io_c::close() {
 
 bool
 mm_file_io_c::eof() {
-  return feof((FILE *)file) != 0 ? true : false;
+  return feof((FILE *)file) != 0;
 }
 
 int
 mm_file_io_c::truncate(int64_t pos) {
+  cached_size = -1;
   return ftruncate(fileno((FILE *)file), pos);
 }
 
@@ -419,6 +421,7 @@ mm_file_io_c::write(const void *buffer,
   }
 
   m_current_position += bytes_written;
+  cached_size         = -1;
 
   return bytes_written;
 }
@@ -432,6 +435,8 @@ int
 mm_file_io_c::truncate(int64_t pos) {
   bool result;
 
+  cached_size = -1;
+
   save_pos();
   if (setFilePointer2(pos)) {
     result = SetEndOfFile((HANDLE)file);
@@ -813,14 +818,14 @@ mm_io_c::write_bom(const string &charset) {
 
 int64_t
 mm_io_c::get_size() {
-  int64_t size;
+  if (-1 == cached_size) {
+    save_pos();
+    setFilePointer(0, seek_end);
+    cached_size = getFilePointer();
+    restore_pos();
+  }
 
-  save_pos();
-  setFilePointer(0, seek_end);
-  size = getFilePointer();
-  restore_pos();
-
-  return size;
+  return cached_size;
 }
 
 int
@@ -1031,6 +1036,8 @@ mm_mem_io_c::write(const void *buffer,
   memcpy(&mem[pos], buffer, wbytes);
   pos += wbytes;
 
+  cached_size = -1;
+
   return wbytes;
 }
 
@@ -1262,10 +1269,14 @@ mm_stdio_c::write(const void *buffer,
 
   fflush(stdout);
 
+  cached_size = -1;
+
   return bytes_written;
 
 #else  // defined(SYS_WINDOWS)
 
+  cached_size = -1;
+
   return fwrite(buffer, 1, size, stdout);
 #endif // defined(SYS_WINDOWS)
 }
