@@ -13,7 +13,7 @@
    licensed under the LGPL.
 
    \file
-   \version $Id: mpeg4_common.cpp 3575 2007-08-15 17:59:22Z mosu $
+   \version $Id: mpeg4_common.cpp 3763 2008-02-28 13:49:11Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
 */
@@ -1161,7 +1161,7 @@ mpeg4::p10::avc_es_parser_c::flush_unhandled_nalus() {
   m_unhandled_nalus.clear();
 }
 
-static int klaus = 0;
+// static int klaus = 0;
 
 void
 mpeg4::p10::avc_es_parser_c::handle_slice_nalu(memory_cptr &nalu) {
@@ -1176,8 +1176,8 @@ mpeg4::p10::avc_es_parser_c::handle_slice_nalu(memory_cptr &nalu) {
   }
 
   if (!parse_slice(nalu, si)) {
-    mxwarn("Slice parser error %d.\n", klaus);
-    ++klaus;
+//     mxwarn("Slice parser error %d.\n", klaus);
+//     ++klaus;
     return;
   }
 
