@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xtr_vobsub.cpp 3542 2007-06-30 10:42:33Z mosu $
+   $Id: xtr_vobsub.cpp 3754 2008-02-25 17:13:13Z mosu $
 
    extracts tracks from Matroska files into other files
 
@@ -80,13 +80,13 @@ xtr_vobsub_c::create_file(xtr_base_c *_master,
   language = kt_get_language(track);
 
   if (NULL == master) {
-    string file_name = base_name + ".sub";
+    string sub_file_name = base_name + ".sub";
 
     try {
-      out = new mm_file_io_c(file_name, MODE_CREATE);
+      out = new mm_file_io_c(sub_file_name, MODE_CREATE);
     } catch (...) {
       mxerror("Failed to create the VobSub data file '%s': %d (%s)\n",
-              file_name.c_str(), errno, strerror(errno));
+              sub_file_name.c_str(), errno, strerror(errno));
     }
 
   } else {
