@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_aac.cpp 2809 2005-02-24 21:05:35Z mosu $
+   $Id: r_aac.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    AAC demultiplexer module
 
@@ -22,6 +22,7 @@
 #include "error.h"
 #include "r_aac.h"
 #include "p_aac.h"
+#include "output_control.h"
 
 #define PROBESIZE 8192
 
@@ -67,8 +68,9 @@ aac_reader_c::probe_file(mm_io_c *io,
 
 aac_reader_c::aac_reader_c(track_info_c &_ti)
   throw (error_c):
-  generic_reader_c(_ti) {
-  int adif, i;
+  generic_reader_c(_ti),
+  sbr_status_set(false) {
+  int adif, detected_profile;
 
   try {
     io = new mm_file_io_c(ti.fname);
@@ -91,11 +93,23 @@ aac_reader_c::aac_reader_c(track_info_c &_ti)
     bytes_processed = 0;
     ti.id = 0;                 // ID for this track.
 
-    for (i = 0; i < ti.aac_is_sbr.size(); i++)
-      if ((ti.aac_is_sbr[i] == 0) || (ti.aac_is_sbr[i] == -1)) {
-        aacheader.profile = AAC_PROFILE_SBR;
-        break;
-      }
+    detected_profile = aacheader.profile;
+
+    if (24000 >= aacheader.sample_rate)
+      aacheader.profile = AAC_PROFILE_SBR;
+
+    if ((map_has_key(ti.all_aac_is_sbr, 0) && ti.all_aac_is_sbr[0]) ||
+        (map_has_key(ti.all_aac_is_sbr, -1) && ti.all_aac_is_sbr[-1]))
+      aacheader.profile = AAC_PROFILE_SBR;
+
+    if ((map_has_key(ti.all_aac_is_sbr, 0) && !ti.all_aac_is_sbr[0]) ||
+        (map_has_key(ti.all_aac_is_sbr, -1) && !ti.all_aac_is_sbr[-1]))
+      aacheader.profile = detected_profile;
+
+    if (map_has_key(ti.all_aac_is_sbr, 0) ||
+        map_has_key(ti.all_aac_is_sbr, -1))
+      sbr_status_set = true;
+
   } catch (...) {
     throw error_c("aac_reader: Could not open the file.");
   }
@@ -114,7 +128,7 @@ aac_reader_c::create_packetizer(int64_t) {
 
   if (NPTZR() != 0)
     return;
-  if (aacheader.profile != AAC_PROFILE_SBR)
+  if (!sbr_status_set)
     mxwarn("AAC files may contain HE-AAC / AAC+ / SBR AAC audio. "
            "This can NOT be detected automatically. Therefore you have to "
            "specifiy '--aac-is-sbr 0' manually for this input file if the "
@@ -135,25 +149,24 @@ aac_reader_c::create_packetizer(int64_t) {
 // Try to guess if the MPEG4 header contains the emphasis field (2 bits)
 void
 aac_reader_c::guess_adts_version() {
+  aac_header_t tmp_aacheader;
   int pos;
-  aac_header_t aacheader;
 
   emphasis_present = false;
 
   // Due to the checks we do have an ADTS header at 0.
-  find_aac_header(chunk, INITCHUNKSIZE, &aacheader, emphasis_present);
-  if (aacheader.id != 0)        // MPEG2
+  find_aac_header(chunk, INITCHUNKSIZE, &tmp_aacheader, emphasis_present);
+  if (tmp_aacheader.id != 0)        // MPEG2
     return;
 
   // Now make some sanity checks on the size field.
-  if (aacheader.bytes > 8192) {
+  if (tmp_aacheader.bytes > 8192) {
     emphasis_present = true;    // Looks like it's borked.
     return;
   }
 
   // Looks ok so far. See if the next ADTS is right behind this packet.
-  pos = find_aac_header(&chunk[aacheader.bytes], INITCHUNKSIZE -
-                        aacheader.bytes, &aacheader, emphasis_present);
+  pos = find_aac_header(&chunk[tmp_aacheader.bytes], INITCHUNKSIZE - tmp_aacheader.bytes, &tmp_aacheader, emphasis_present);
   if (pos != 0) {               // Not ok - what do we do now?
     emphasis_present = true;
     return;
@@ -170,9 +183,7 @@ aac_reader_c::read(generic_packetizer_c *,
     PTZR0->flush();
     return FILE_STATUS_DONE;
   }
-
-  memory_c mem(chunk, nread, false);
-  PTZR0->process(mem);
+  PTZR0->process(new packet_t(new memory_c(chunk, nread, false)));
   bytes_processed += nread;
 
   return FILE_STATUS_MOREDATA;
@@ -185,6 +196,8 @@ aac_reader_c::get_progress() {
 
 void
 aac_reader_c::identify() {
-  mxinfo("File '%s': container: AAC\nTrack ID 0: audio (AAC)\n",
-         ti.fname.c_str());
+  string verbose_info = string("aac_is_sbr:") + string(AAC_PROFILE_SBR == aacheader.profile ? "true" : "unknown");
+
+  id_result_container("AAC");
+  id_result_track(0, ID_RESULT_TRACK_AUDIO, "AAC", verbose_info);
 }
