@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_ac3.cpp 3503 2007-03-02 11:17:25Z mosu $
+   $Id: r_ac3.cpp 3759 2008-02-27 15:32:22Z mosu $
 
    AC3 demultiplexer module
 
@@ -91,6 +91,11 @@ ac3_reader_c::read(generic_packetizer_c *,
   PTZR0->process(new packet_t(new memory_c(chunk, nread, false)));
   bytes_processed += nread;
 
+  if ((nread < 4096) || io->eof()) {
+    PTZR0->flush();
+    return FILE_STATUS_DONE;
+  }
+
   return FILE_STATUS_MOREDATA;
 }
 
@@ -101,8 +106,8 @@ ac3_reader_c::get_progress() {
 
 void
 ac3_reader_c::identify() {
-  mxinfo("File '%s': container: AC3\nTrack ID 0: audio (%sAC3)\n",
-         ti.fname.c_str(), 16 == ac3header.bsid ? "E" : "");
+  id_result_container("AC3");
+  id_result_track(0, ID_RESULT_TRACK_AUDIO, 16 == ac3header.bsid ? "EAC3" : "AC3");
 }
 
 int
