@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_dts.cpp 3489 2007-02-03 15:53:12Z mosu $
+   $Id: r_dts.cpp 3759 2008-02-27 15:32:22Z mosu $
 
    DTS demultiplexer module
 
@@ -137,6 +137,11 @@ dts_reader_c::read(generic_packetizer_c *,
   PTZR0->process(new packet_t(new memory_c(buf[cur_buf], nread, false)));
   bytes_processed += nread;
 
+  if ((nread < READ_SIZE) || io->eof()) {
+    PTZR0->flush();
+    return FILE_STATUS_DONE;
+  }
+
   return FILE_STATUS_MOREDATA;
 }
 
@@ -147,6 +152,6 @@ dts_reader_c::get_progress() {
 
 void
 dts_reader_c::identify() {
-  mxinfo("File '%s': container: DTS\nTrack ID 0: audio (DTS)\n",
-         ti.fname.c_str());
+  id_result_container("DTS");
+  id_result_track(0, ID_RESULT_TRACK_AUDIO, "DTS");
 }
