@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_mp3.cpp 2809 2005-02-24 21:05:35Z mosu $
+   $Id: r_mp3.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    MP3 reader module
 
@@ -87,8 +87,7 @@ mp3_reader_c::read(generic_packetizer_c *,
     return FILE_STATUS_DONE;
   }
 
-  memory_c mem(chunk, nread, false);
-  PTZR0->process(mem);
+  PTZR0->process(new packet_t(new memory_c(chunk, nread, false)));
   bytes_processed += nread;
 
   return FILE_STATUS_MOREDATA;
@@ -101,10 +100,8 @@ mp3_reader_c::get_progress() {
 
 void
 mp3_reader_c::identify() {
-  mxinfo("File '%s': container: MP2/MP3\nTrack ID 0: audio (MPEG-%s layer "
-         "%d)\n", ti.fname.c_str(),
-         mp3header.version == 1 ? "1" : mp3header.version == 2 ? "2" : "2.5",
-         mp3header.layer);
+  id_result_container("MP2/MP3");
+  id_result_track(0, ID_RESULT_TRACK_AUDIO, mxsprintf("MPEG-%s layer %d",  mp3header.version == 1 ? "1" : mp3header.version == 2 ? "2" : "2.5", mp3header.layer));
 }
 
 int
