@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_mpeg.cpp 3572 2007-07-10 20:18:46Z mosu $
+   $Id: r_mpeg.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    MPEG ES demultiplexer module
 
@@ -234,8 +234,8 @@ mpeg_es_reader_c::get_progress() {
 
 void
 mpeg_es_reader_c::identify() {
-  mxinfo("File '%s': container: MPEG elementary stream (ES)\n"
-         "Track ID 0: video (MPEG %d)\n", ti.fname.c_str(), version);
+  id_result_container("MPEG elementary stream (ES)");
+  id_result_track(0, ID_RESULT_TRACK_VIDEO, mxsprintf("MPEG %d", version));
 }
 
 // ------------------------------------------------------------------------
@@ -276,6 +276,11 @@ mpeg_ps_reader_c::mpeg_ps_reader_c(track_info_c &_ti)
   throw (error_c):
   generic_reader_c(_ti) {
 
+  init_reader();
+}
+
+void
+mpeg_ps_reader_c::init_reader() {
   int i;
 
   try {
@@ -345,7 +350,7 @@ mpeg_ps_reader_c::mpeg_ps_reader_c(track_info_c &_ti)
           break;
 
         case MPEGVIDEO_MPEG_PROGRAM_END_CODE:
-          done = true;
+          done = !resync_stream(header);
           break;
 
         case MPEGVIDEO_PROGRAM_STREAM_MAP_START_CODE:
@@ -356,7 +361,7 @@ mpeg_ps_reader_c::mpeg_ps_reader_c(track_info_c &_ti)
           if (!mpeg_is_start_code(header)) {
             mxverb(3, "mpeg_ps: unknown header 0x%08x at " LLD "\n",
                    header, io->getFilePointer() - 4);
-            done = true;
+            done = !resync_stream(header);
             break;
           }
 
@@ -755,7 +760,7 @@ mpeg_ps_reader_c::new_stream_v_avc(int id,
     mm_mem_io_c avcc(track->v_avcc->get(), track->v_avcc->get_size());
     mm_mem_io_c new_avcc(NULL, track->v_avcc->get_size(), 1024);
     memory_cptr nalu(new memory_c());
-    int num_sps, sps, length;
+    int num_sps, sps, sps_length;
     sps_info_t sps_info;
 
     avcc.read(nalu, 5);
@@ -768,13 +773,13 @@ mpeg_ps_reader_c::new_stream_v_avc(int id,
     for (sps = 0; sps < num_sps; sps++) {
       bool abort;
 
-      length = avcc.read_uint16_be();
-      if ((length + avcc.getFilePointer()) >= track->v_avcc->get_size())
-        length = track->v_avcc->get_size() - avcc.getFilePointer();
-      avcc.read(nalu, length);
+      sps_length = avcc.read_uint16_be();
+      if ((sps_length + avcc.getFilePointer()) >= track->v_avcc->get_size())
+        sps_length = track->v_avcc->get_size() - avcc.getFilePointer();
+      avcc.read(nalu, sps_length);
 
       abort = false;
-      if ((0 < length) && ((nalu->get()[0] & 0x1f) == 7)) {
+      if ((0 < sps_length) && ((nalu->get()[0] & 0x1f) == 7)) {
         nalu_to_rbsp(nalu);
         if (!mpeg4::p10::parse_sps(nalu, sps_info, true))
           throw false;
@@ -1021,15 +1026,19 @@ mpeg_ps_reader_c::find_next_packet(int &id,
           break;
 
         case MPEGVIDEO_MPEG_PROGRAM_END_CODE:
-          return false;
+          if (!resync_stream(header))
+            return false;
 
         case MPEGVIDEO_PROGRAM_STREAM_MAP_START_CODE:
           parse_program_stream_map();
           break;
 
         default:
-          if (!mpeg_is_start_code(header) && !resync_stream(header))
-            return false;
+          if (!mpeg_is_start_code(header)) {
+            if (!resync_stream(header))
+              return false;
+            continue;
+          }
 
           id = header & 0xff;
           return true;
@@ -1286,44 +1295,37 @@ mpeg_ps_reader_c::get_progress() {
 
 void
 mpeg_ps_reader_c::identify() {
+  vector<string> verbose_info;
   int i;
 
-  mxinfo("File '%s': container: MPEG %d program stream (PS)\n",
-         ti.fname.c_str(), version);
+  id_result_container(mxsprintf("MPEG %d program stream (PS)", version));
+
   for (i = 0; i < tracks.size(); i++) {
     mpeg_ps_track_ptr &track = tracks[i];
-    string info;
 
-    if (identify_verbose) {
-      if (FOURCC('A', 'V', 'C', '1') == track->fourcc) {
-        if (0 != track->v_aspect_ratio)
-          info += mxsprintf("display_dimensions:%dx%d ",
-                            track->v_dwidth, track->v_dheight);
-      }
-      info += "packetizer:mpeg4_p10_es_video ";
+    verbose_info.clear();
+
+    if (FOURCC('A', 'V', 'C', '1') == track->fourcc) {
+      if (0 != track->v_aspect_ratio)
+        verbose_info.push_back(mxsprintf("display_dimensions:%dx%d", track->v_dwidth, track->v_dheight));
+      verbose_info.push_back("packetizer:mpeg4_p10_es_video");
     }
 
-    info += mxsprintf("stream_id:%#x", track->id);
+    verbose_info.push_back(mxsprintf("stream_id:%#x", track->id));
 
-    if (!info.empty()) {
-      info = mxsprintf(" [%s]", info.c_str());
-    }
-
-    mxinfo("Track ID %d: %s (%s)%s\n", i,
-           track->type == 'a' ? "audio" : "video",
-           track->fourcc == FOURCC('M', 'P', 'G', '1') ? "MPEG-1" :
-           track->fourcc == FOURCC('M', 'P', 'G', '2') ? "MPEG-2" :
-           track->fourcc == FOURCC('A', 'V', 'C', '1') ? "AVC/h.264" :
-           track->fourcc == FOURCC('M', 'P', '1', ' ') ? "MPEG-1 layer 1" :
-           track->fourcc == FOURCC('M', 'P', '2', ' ') ? "MPEG-1 layer 2" :
-           track->fourcc == FOURCC('M', 'P', '3', ' ') ? "MPEG-1 layer 3" :
-           track->fourcc == FOURCC('A', 'C', '3', ' ') ?
-           (16 == track->a_bsid ? "EAC3" : "AC3") :
-           track->fourcc == FOURCC('D', 'T', 'S', ' ') ? "DTS" :
-           track->fourcc == FOURCC('P', 'C', 'M', ' ') ? "PCM" :
-           track->fourcc == FOURCC('L', 'P', 'C', 'M') ? "LPCM" :
-           "unknown",
-           info.c_str());
+    id_result_track(i, track->type == 'a' ? ID_RESULT_TRACK_AUDIO : ID_RESULT_TRACK_VIDEO,
+                    track->fourcc == FOURCC('M', 'P', 'G', '1') ? "MPEG-1"         :
+                    track->fourcc == FOURCC('M', 'P', 'G', '2') ? "MPEG-2"         :
+                    track->fourcc == FOURCC('A', 'V', 'C', '1') ? "AVC/h.264"      :
+                    track->fourcc == FOURCC('M', 'P', '1', ' ') ? "MPEG-1 layer 1" :
+                    track->fourcc == FOURCC('M', 'P', '2', ' ') ? "MPEG-1 layer 2" :
+                    track->fourcc == FOURCC('M', 'P', '3', ' ') ? "MPEG-1 layer 3" :
+                    track->fourcc == FOURCC('A', 'C', '3', ' ') ? (16 == track->a_bsid ? "EAC3" : "AC3") :
+                    track->fourcc == FOURCC('D', 'T', 'S', ' ') ? "DTS"            :
+                    track->fourcc == FOURCC('P', 'C', 'M', ' ') ? "PCM"            :
+                    track->fourcc == FOURCC('L', 'P', 'C', 'M') ? "LPCM"           :
+                    "unknown",
+                    verbose_info);
   }
 }
 
