@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_ssa.cpp 3573 2007-07-19 11:20:45Z mosu $
+   $Id: r_ssa.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    SSA/ASS subtitle parser
 
@@ -437,6 +437,6 @@ ssa_reader_c::get_progress() {
 
 void
 ssa_reader_c::identify() {
-  mxinfo("File '%s': container: SSA/ASS\nTrack ID 0: subtitles "
-         "(SSA/ASS)\n", ti.fname.c_str());
+  id_result_container("SSA/ASS");
+  id_result_track(0, ID_RESULT_TRACK_SUBTITLES, "SSA/ASS");
 }
