@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_usf.cpp 2985 2005-07-16 14:51:18Z mosu $
+   $Id: r_usf.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    USF subtitle reader
 
@@ -131,8 +131,11 @@ usf_reader_c::start_element_cb(const char *name,
   if (node == "USFSubtitles.metadata.language") {
     for (i = 0; (NULL != atts[i]) && (NULL != atts[i + 1]); i += 2)
       if (!strcmp(atts[i], "code") && (0 != atts[i + 1][0])) {
-        if (is_valid_iso639_2_code(atts[i + 1]))
-          m_default_language = atts[i + 1];
+        int index;
+
+        index = map_to_iso639_2_code(atts[i + 1]);
+        if (-1 != index)
+          m_default_language = iso639_languages[index].iso639_2_code;
         else if (!identifying)
           mxwarn(FMT_FN "The default language code '%s' is not a valid "
                  "ISO639-2 language code and will be ignored.\n",
@@ -163,8 +166,12 @@ usf_reader_c::start_element_cb(const char *name,
   } else if (node == "USFSubtitles.subtitles.language") {
     for (i = 0; (NULL != atts[i]) && (NULL != atts[i + 1]); i += 2)
       if (!strcmp(atts[i], "code") && (0 != atts[i + 1][0])) {
-        if (is_valid_iso639_2_code(atts[i + 1]))
-          m_tracks[m_tracks.size() - 1].m_language = atts[i + 1];
+        int index;
+
+        index = map_to_iso639_2_code(atts[i + 1]);
+        if (-1 != index)
+          m_tracks[m_tracks.size() - 1].m_language =
+            iso639_languages[index].iso639_2_code;
         else if (!identifying)
           mxwarn(FMT_TID "The language code '%s' is not a valid "
                  "ISO639-2 language code and will be ignored.\n",
@@ -291,7 +298,7 @@ usf_reader_c::read(generic_packetizer_c *ptzr,
 
   track = NULL;
   for (i = 0; m_tracks.size() > i; ++i)
-    if (PTZR(m_tracks[i].m_ptzr) == ptzr) {
+    if ((-1 != m_tracks[i].m_ptzr) && (PTZR(m_tracks[i].m_ptzr) == ptzr)) {
       track = &m_tracks[i];
       break;
     }
@@ -344,20 +351,19 @@ usf_reader_c::try_to_parse_timecode(const char *s) {
 
 void
 usf_reader_c::identify() {
+  vector<string> verbose_info;
   int i;
 
-  mxinfo("File '%s': container: USF\n", ti.fname.c_str());
+  id_result_container("USF");
+
   for (i = 0; m_tracks.size() > i; ++i) {
     usf_track_t &track = m_tracks[i];
-    string info;
 
-    mxinfo("Track ID %d: subtitles (USF)", i);
-    if (identify_verbose) {
-      info = " [";
-      if (track.m_language != "")
-        info += "language:" + escape(track.m_language) + " ";
-      mxinfo("%s]", info.c_str());
-    }
-    mxinfo("\n");
+    verbose_info.clear();
+
+    if (!track.m_language.empty())
+      verbose_info.push_back(string("language:") + escape(track.m_language));
+
+    id_result_track(i, ID_RESULT_TRACK_SUBTITLES, "USF", verbose_info);
   }
 }
