@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_vobbtn.cpp 2932 2005-05-25 21:31:26Z mosu $
+   $Id: r_vobbtn.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    VobBtn stream reader
 
@@ -86,7 +86,8 @@ vobbtn_reader_c::~vobbtn_reader_c() {
 void
 vobbtn_reader_c::create_packetizer(int64_t tid) {
   ti.id = tid;
-  add_packetizer(new vobbtn_packetizer_c(this, width, height, ti));
+  if (demuxing_requested('s', tid))
+    add_packetizer(new vobbtn_packetizer_c(this, width, height, ti));
 }
 
 file_status_e
@@ -121,7 +122,6 @@ vobbtn_reader_c::get_progress() {
 
 void
 vobbtn_reader_c::identify() {
-  mxinfo("File '%s': container: VobBtn\n", ti.fname.c_str());
-  mxinfo("Track ID 0: MPEG PCI buttons (width %d / height %d)\n", width,
-         height);
+  id_result_container("VobBtn");
+  id_result_track(0, ID_RESULT_TRACK_BUTTONS, mxsprintf("MPEG PCI, width %d / height %d", width, height));
 }
