@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_wavpack.cpp 2951 2005-06-10 07:12:50Z mosu $
+   $Id: r_wavpack.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    WAVPACK demultiplexer module
 
@@ -235,9 +235,8 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
         databuffer += block_size;
       }
 
-      packet->memory_adds.push_back(memory_cptr(new memory_c(chunk_correc,
-                                                             data_size,
-                                                             true)));
+      packet->data_adds.push_back(memory_cptr(new memory_c(chunk_correc,
+                                                           data_size, true)));
     }
   }
 
@@ -253,6 +252,6 @@ wavpack_reader_c::get_progress() {
 
 void
 wavpack_reader_c::identify() {
-  mxinfo("File '%s': container: WAVPACK\nTrack ID 0: audio (WAVPACK)\n",
-         ti.fname.c_str());
+  id_result_container("WAVPACK");
+  id_result_track(0, ID_RESULT_TRACK_AUDIO, "WAVPACK");
 }
