@@ -8,7 +8,7 @@
    or visit http://www.gnu.org/copyleft/gpl.html
 
    \file
-   \version $Id: mkvmerge.cpp 3579 2007-08-19 08:53:32Z mosu $
+   \version $Id: mkvmerge.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
    \author Modified by Steve Lhomme <steve.lhomme@free.fr>.
@@ -385,6 +385,7 @@ identify(const string &filename) {
   create_readers();
 
   files[0].reader->identify();
+  files[0].reader->display_identification_results();
 }
 
 /** \brief Parse a number postfixed with a time-based unit
@@ -1439,7 +1440,7 @@ guess_mime_type_and_report(string file_name) {
 }
 
 static void
-handle_segmentinfo(KaxInfo *kax_info_chap) {
+handle_segmentinfo() {
   KaxSegmentFamily *family;
   EbmlBinary *uid;
 
@@ -1877,7 +1878,7 @@ parse_args(vector<string> args) {
 
       segmentinfo_file_name = next_arg;
       kax_info_chap = parse_segmentinfo(segmentinfo_file_name, false);
-      handle_segmentinfo(kax_info_chap);
+      handle_segmentinfo();
 
       sit++;
 
