@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mkvmerge.h 2711 2005-01-12 15:03:47Z mosu $
+   $Id: mkvmerge.h 3523 2007-04-18 17:20:18Z mosu $
 
    definition of global variables found in mkvmerge.cpp
 
@@ -28,28 +28,32 @@ enum display_priority_e {
 /* file types */
 enum file_type_e {
   FILE_TYPE_IS_UNKNOWN = 0,
-  FILE_TYPE_OGM,
-  FILE_TYPE_AVI,
-  FILE_TYPE_WAV,
-  FILE_TYPE_SRT,
-  FILE_TYPE_MP3,
-  FILE_TYPE_AC3,
-  FILE_TYPE_CHAPTERS,
-  FILE_TYPE_MICRODVD,
-  FILE_TYPE_VOBSUB,
-  FILE_TYPE_MATROSKA,
-  FILE_TYPE_DTS,
   FILE_TYPE_AAC,
-  FILE_TYPE_SSA,
-  FILE_TYPE_REAL,
-  FILE_TYPE_QTMP4,
+  FILE_TYPE_AC3,
+  FILE_TYPE_AVC_ES,
+  FILE_TYPE_AVI,
+  FILE_TYPE_CHAPTERS,
+  FILE_TYPE_COREPICTURE,
+  FILE_TYPE_DTS,
   FILE_TYPE_FLAC,
-  FILE_TYPE_TTA,
+  FILE_TYPE_MATROSKA,
+  FILE_TYPE_MICRODVD,
+  FILE_TYPE_MP3,
   FILE_TYPE_MPEG_ES,
-  FILE_TYPE_VOBBTN,
-  FILE_TYPE_WAVPACK4,
   FILE_TYPE_MPEG_PS,
-  FILE_TYPE_MAX = FILE_TYPE_MPEG_PS
+  FILE_TYPE_MPEG_TS,
+  FILE_TYPE_OGM,
+  FILE_TYPE_QTMP4,
+  FILE_TYPE_REAL,
+  FILE_TYPE_SRT,
+  FILE_TYPE_SSA,
+  FILE_TYPE_TTA,
+  FILE_TYPE_USF,
+  FILE_TYPE_VOBBTN,
+  FILE_TYPE_VOBSUB,
+  FILE_TYPE_WAV,
+  FILE_TYPE_WAVPACK4,
+  FILE_TYPE_MAX = FILE_TYPE_WAVPACK4
 };
 
 int64_t create_track_number(generic_reader_c *reader, int64_t tid);
