@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: pr_generic.cpp 3533 2007-06-23 14:56:28Z mosu $
+   $Id: pr_generic.cpp 3755 2008-02-26 19:08:38Z mosu $
 
    functions common for all readers/packetizers
 
@@ -48,7 +48,8 @@ vector<generic_packetizer_c *> ptzrs_in_header_order;
 
 generic_packetizer_c::generic_packetizer_c(generic_reader_c *nreader,
                                            track_info_c &_ti)
-  throw(error_c): ti(_ti) {
+  throw(error_c):
+  next_packet_wo_assigned_timecode(0), ti(_ti) {
   int i;
 
 #ifdef DEBUG
@@ -955,6 +956,10 @@ generic_packetizer_c::get_packet() {
 
   enqueued_bytes -= pack->data->get_size();
 
+  --next_packet_wo_assigned_timecode;
+  if (next_packet_wo_assigned_timecode < 0)
+    next_packet_wo_assigned_timecode = 0;
+
   return pack;
 }
 
@@ -975,6 +980,8 @@ generic_packetizer_c::apply_factory_once(packet_cptr &packet) {
     max_timecode_seen = packet->assigned_timecode + packet->duration;
   if (reader->max_timecode_seen < max_timecode_seen)
     reader->max_timecode_seen = max_timecode_seen;
+
+  ++next_packet_wo_assigned_timecode;
 }
 
 void
@@ -985,7 +992,7 @@ generic_packetizer_c::apply_factory() {
     return;
 
   // Find the first packet to which the factory hasn't been applied yet.
-  p_start = packet_queue.begin();
+  p_start = packet_queue.begin() + next_packet_wo_assigned_timecode;
   while ((packet_queue.end() != p_start) && (*p_start)->factory_applied)
     ++p_start;
 
@@ -1393,6 +1400,91 @@ generic_reader_c::flush_packetizers() {
     (*it)->flush();
 }
 
+void
+generic_reader_c::id_result_container(const string &info,
+                                      const string &verbose_info) {
+  id_results_container.info = info;
+  id_results_container.verbose_info.clear();
+  if (!verbose_info.empty())
+    id_results_container.verbose_info.push_back(verbose_info);
+}
+
+void
+generic_reader_c::id_result_container(const string &info,
+                                      const vector<string> &verbose_info) {
+  id_results_container.info         = info;
+  id_results_container.verbose_info = verbose_info;
+}
+
+void
+generic_reader_c::id_result_track(int64_t track_id,
+                                  const string &type,
+                                  const string &info,
+                                  const string &verbose_info) {
+  id_result_t result(track_id, type, info, empty_string, 0);
+  if (!verbose_info.empty())
+    result.verbose_info.push_back(verbose_info);
+  id_results_tracks.push_back(result);
+}
+
+void
+generic_reader_c::id_result_track(int64_t track_id,
+                                  const string &type,
+                                  const string &info,
+                                  const vector<string> &verbose_info) {
+  id_result_t result(track_id, type, info, empty_string, 0);
+  result.verbose_info = verbose_info;
+  id_results_tracks.push_back(result);
+}
+
+void
+generic_reader_c::id_result_attachment(int64_t attachment_id,
+                                       const string &type,
+                                       int size,
+                                       const string &file_name,
+                                       const string &description) {
+  id_result_t result(attachment_id, type, file_name, description, size);
+  id_results_attachments.push_back(result);
+}
+
+void
+generic_reader_c::display_identification_results() {
+  int i;
+
+  mxinfo("File '%s': container: %s", ti.fname.c_str(), id_results_container.info.c_str());
+
+  if (identify_verbose && !id_results_container.verbose_info.empty())
+    mxinfo(" [%s]", join(" ", id_results_container.verbose_info).c_str());
+
+  mxinfo("\n");
+
+
+  for (i = 0; i < id_results_tracks.size(); ++i) {
+    id_result_t &result = id_results_tracks[i];
+
+    mxinfo("Track ID " LLD ": %s (%s)", result.id, result.type.c_str(), result.info.c_str());
+
+    if (identify_verbose && !result.verbose_info.empty())
+      mxinfo(" [%s]", join(" ", result.verbose_info).c_str());
+
+    mxinfo("\n");
+  }
+
+  for (i = 0; i < id_results_attachments.size(); ++i) {
+    id_result_t &result = id_results_attachments[i];
+
+    mxinfo("Attachment ID " LLD ": type '%s', size " LLD " bytes", result.id, result.type.c_str(), result.size);
+
+    if (!result.description.empty())
+      mxinfo(", description '%s'", result.description.c_str());
+
+    if (!result.info.empty())
+      mxinfo(", file name '%s'", result.info.c_str());
+
+    mxinfo("\n");
+  }
+}
+
 //
 //--------------------------------------------------------------------
 
