@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: tab_chapters.cpp 3559 2007-07-05 14:56:32Z mosu $
+   $Id: tab_chapters.cpp 3754 2008-02-25 17:13:13Z mosu $
 
    "chapter editor" tab
 
@@ -49,8 +49,8 @@ private:
 public:
   chapters_drop_target_c(tab_chapters *n_owner):
     owner(n_owner) {};
-  virtual bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString &files) {
-    owner->load(files[0]);
+  virtual bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString &dropped_files) {
+    owner->load(dropped_files[0]);
 
     return true;
   }
